pub fn select_solver<S: Scalar>(problem: &OptimProblem<S>) -> SolverChoiceExpand description
Select the best solver for the given problem structure.
pub fn select_solver<S: Scalar>(problem: &OptimProblem<S>) -> SolverChoiceSelect the best solver for the given problem structure.