Module lbfgsb

Module lbfgsb 

L-BFGS-B: bound-constrained limited-memory BFGS.

Implements a projected L-BFGS method for minimization with simple box constraints on variables: lo_i <= x_i <= hi_i.

Author: Moussa Leblouba Date: 8 February 2026 Modified: 2 May 2026

Structs

LbfgsBOptions
Options for L-BFGS-B.

Functions

lbfgsb_minimize
Minimize f subject to box constraints using projected L-BFGS.
project
Project x onto the feasible box defined by bounds.
projected_gradient_norm
Compute the projected gradient norm: ||P(x - g) - x||_inf.