Revised Simplex method for Linear Programming.
Solves: minimize c^T x subject to A_ineq x <= b_ineq, A_eq x = b_eq, x >= 0.
Uses two-phase simplex: Phase I finds a basic feasible solution, Phase II optimizes the objective.
Author: Moussa Leblouba Date: 8 February 2026 Modified: 2 May 2026
Structs
- LPOptions
- Options for the LP solver.
Functions
- simplex_
solve - Solve a linear program using the Revised Simplex method.