RobustProblem

Struct RobustProblem 

pub struct RobustProblem<S: Scalar> { /* private fields */ }
Declarative builder for robust optimization problems.

The objective and constraints are functions of both decision variables x and uncertain parameters p. The solver reformulates the problem so that constraints hold under worst-case parameter perturbations at the specified confidence level.

Implementations

Source

impl<S: Scalar> RobustProblem<S>

pub fn new(n: usize) -> Self

Create a new robust optimization problem with n decision variables.

pub fn x0(self, x0: &[S]) -> Self

Set the initial point.

pub fn bounds(self, i: usize, lo_hi: (S, S)) -> Self

Set bounds for variable i.

pub fn all_bounds(self, bounds: &[(S, S)]) -> Self

Set bounds for all variables at once.

pub fn objective<F>(self, f: F) -> Self
where F: Fn(&[S], &[S]) -> S + Send + Sync + 'static,

Set the parameterized objective function f(x, params).

pub fn gradient<G>(self, g: G) -> Self
where G: Fn(&[S], &[S], &mut [S]) + Send + Sync + 'static,

Set the gradient of the objective w.r.t. x.

g(x, params, grad_out) writes the gradient into grad_out.

pub fn constraint_ineq<F>(self, f: F) -> Self
where F: Fn(&[S], &[S]) -> S + Send + Sync + 'static,

Add an inequality constraint g(x, params) <= 0.

pub fn constraint_eq<F>(self, f: F) -> Self
where F: Fn(&[S], &[S]) -> S + Send + Sync + 'static,

Add an equality constraint h(x, params) = 0.

pub fn param(self, name: &str, mean: S, std: S) -> Self

Add a single uncertain parameter.

pub fn params(self, params: Vec<UncertainParam<S>>) -> Self

Add multiple uncertain parameters at once.

pub fn confidence(self, level: S) -> Self

Set the confidence level (must be in (0, 1)).

pub fn max_iter(self, n: usize) -> Self

Set the maximum number of optimizer iterations.

Source

impl<S: Scalar + SimpleEntity + Conjugate<Canonical = S> + ComplexField> RobustProblem<S>

pub fn solve(self) -> Result<RobustResult<S>, OptimError>

Solve the robust optimization problem.

  1. Computes worst-case parameter vectors for each inequality constraint.
  2. Reformulates as a standard OptimProblem with tightened constraints.
  3. Solves the reformulated problem.
  4. Computes parametric sensitivity and solution uncertainty.