pub fn simplex_solve<S: Scalar + SimpleEntity + Conjugate<Canonical = S> + ComplexField>(
c: &[S],
a_ineq: &[Vec<S>],
b_ineq: &[S],
a_eq: &[Vec<S>],
b_eq: &[S],
opts: &LPOptions<S>,
) -> Result<OptimResult<S>, OptimError>Expand description
Solve a linear program using the Revised Simplex method.
Standard form conversion
The user provides:
c: objective coefficients (minimize c^T x)a_ineq: rows of A for inequality constraints A_ineq x <= b_ineqb_ineq: RHS of inequality constraintsa_eq: rows of A for equality constraints A_eq x = b_eqb_eq: RHS of equality constraints- All variables assumed non-negative (x >= 0)
Internally converts to standard form by adding slack variables: minimize c^T x subject to [A_eq; A_ineq | I] [x; s] = [b_eq; b_ineq], x >= 0, s >= 0